Package: pqrBayes
Type: Package
Title: Bayesian Penalized Quantile Regression
Version: 1.2.2
Date: 2026-04-28
Authors@R: c( 
              person("Kun", "Fan", role = "aut"),
              person("Cen", "Wu", role = c("aut", "cre"),email = "wucen@ksu.edu"),
              person("Jie", "Ren", role = "aut"),
              person("Xiaoxi", "Li", role = "aut"),
              person("Fei", "Zhou", role = "aut"))
Description: Bayesian regularized quantile regression utilizing two major classes of shrinkage priors 
    (the spike-and-slab priors and the horseshoe family of priors) leads to efficient Bayesian 
    shrinkage estimation, variable selection and valid statistical inference. In this package, 
    we have implemented robust Bayesian variable selection with spike-and-slab priors under 
    high-dimensional linear regression models (Fan et al. (2024) <doi:10.3390/e26090794> and  
    Ren et al. (2023) <doi:10.1111/biom.13670>), and regularized quantile varying
    coefficient models (Zhou et al.(2023) <doi:10.1016/j.csda.2023.107808>). In particular, 
    valid robust Bayesian inferences under both models in the presence of heavy-tailed errors
    can be validated on finite samples. Additional models with spike-and-slab priors include 
    robust Bayesian group LASSO and robust binary Bayesian LASSO (Fan and Wu (2025) 
    <doi:10.1002/sta4.70078>). Besides, robust sparse Bayesian regression with the horseshoe
    family of (horseshoe, horseshoe+ and regularized horseshoe) priors has also been implemented
    and yielded valid inference results under heavy-tailed model errors (Fan et al.(2026) 
    <doi:10.1016/j.csda.2026.108358>). The Markov chain Monte Carlo (MCMC) algorithms of 
    the proposed and alternative models are implemented in C++. 
Depends: R (>= 3.5.0)
License: GPL-2
Encoding: UTF-8
URL: https://github.com/cenwu/pqrBayes
BugReports: https://github.com/cenwu/pqrBayes/issues
LazyData: true
Imports: Rcpp,glmnet,splines, stats
LinkingTo: Rcpp, RcppArmadillo
RoxygenNote: 7.3.3
NeedsCompilation: yes
Repository: CRAN
Packaged: 2026-04-30 03:43:43 UTC; cenwu
Author: Kun Fan [aut],
  Cen Wu [aut, cre],
  Jie Ren [aut],
  Xiaoxi Li [aut],
  Fei Zhou [aut]
Maintainer: Cen Wu <wucen@ksu.edu>
Date/Publication: 2026-04-30 07:10:02 UTC
Built: R 4.5.2; aarch64-apple-darwin20; 2026-04-30 11:01:27 UTC; unix
Archs: pqrBayes.so.dSYM
