# Generated by roxygen2: do not edit by hand

S3method(print,pqrBayes)
S3method(print,pqrBayes.pred)
S3method(print,pqrBayes.select)
export(coverage)
export(estimation.pqrBayes)
export(pqrBayes)
export(pqrBayes.select)
export(predict_pqrBayes)
importFrom(Rcpp,sourceCpp)
useDynLib(pqrBayes, .registration = TRUE)
